@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.05';
+$HTTP::BrowserDetect::VERSION = '2.06';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -129,7 +129,7 @@ our @ROBOT_TESTS = qw(
     linkchecker     yandeximages   specialarchiver
     yandex          java           lib
     indy            golib          rubylib
-    apache
+    apache          msoffice
 );
 
 our @MISC_TESTS = qw(
@@ -181,6 +181,7 @@ my %ROBOT_NAMES = (
     mj12bot         => 'Majestic-12 DSearch',
     msn             => 'MSN',
     msnmobile       => 'MSN Mobile',
+    msoffice        => 'Microsoft Office',
     puf             => 'puf',
     robot           => 'robot',
     rubylib         => 'Ruby http library',
@@ -511,7 +512,7 @@ sub _init_core {
         $browser_tests->{epiphany} = 1;
     }
     elsif ( $ua
-        =~ m{^mozilla/.+windows (?:nt|phone) \d{2}\.\d+;.+ applewebkit/.+ chrome/.+ safari/.+ edge/[\d.]+$}
+        =~ m{^mozilla/.+windows (?:nt|phone) \d{2}\.\d+;?.+ applewebkit/.+ chrome/.+ safari/.+ edge/[\d.]+$}
         ) {
         $browser        = 'edge';
         $browser_string = 'Edge';
@@ -840,6 +841,9 @@ sub _init_robots {
     elsif ( index( $ua, "msnbot" ) != -1 || index( $ua, "bingbot" ) != -1 ) {
         $r = 'msn';
     }
+    elsif ( index( $ua, "microsoft office existence discovery" ) != -1 ) {
+        $r = 'msoffice';
+    }
     elsif ( index( $ua, "ahrefsbot" ) != -1 ) {
         $r = 'ahrefs';
     }
@@ -2437,7 +2441,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.05
+version 2.06
 
 =head1 SYNOPSIS
 
@@ -2637,7 +2641,7 @@ can be detected.
 If the user agent appears to be a robot, spider, crawler, or other
 automated Web client, this returns one of the following values:
 
-lwp, slurp, yahoo, msnmobile, msn, ahrefs, altavista, apache,
+lwp, slurp, yahoo, msnmobile, msn, msoffice, ahrefs, altavista, apache,
 askjeeves, baidu, curl, facebook, getright, googleadsbot,
 googleadsense, googlebotimage, googlebotnews, googlebotvideo,
 googlemobile, google, golib, indy, infoseek, linkexchange,
@@ -2905,6 +2909,8 @@ value. This is by no means a complete list of robots that exist on the Web.
 
 =head3 msn (same as bing)
 
+=head3 msoffice
+
 =head3 puf
 
 =head3 rubylib
@@ -3171,6 +3177,8 @@ Andrew Moise
 
 Atsushi Kato
 
+Marco Fontani
+
 =head1 TO DO
 
 POD coverage is not 100%.
